Noticias Perú, Fernando Barrios, Corrupción, Nueva Zelanda, Apra, Corea, Príncipes de Asturias, Corrupción, Benedicto XVI, Champions, Torneo peruano, Goles, Camboya, Mercedes Aráoz, Metropolitano, Encuesta de intención de voto, Sendero Luminoso | El Comercio Perú
Description: Noticias del Perú y del mundo. El Comercio.pe informa sobre actualidad, política, elecciones, gastronomía, espectáculos y deportes. Tiene blogs y la edición impresa completa. Videos y fotos.

- Móvil
- RSS
- La Comunidad en Tiempo Real
  Ingresa o Registrarse

# Noticias Perú, Fernando Barrios, Corrupción, Nueva Zelanda, Apra, Corea, Príncipes de Asturias, Corrupción, Benedicto XVI, Champions, Torneo peruano, Goles, Camboya, Mercedes Aráoz, Metropolitano, Encuesta de intención de voto, Sendero Luminoso, El Comercio Perú

Agréganos: Facebook | Twitter | Página de Inicio

24 de noviembre del 2010 | 18 °C | 148011 Usuarios

## Ex ministro Barrios es "un hombre extraordinario", dice su sucesor Hidalgo

Hace 1 hora 2041 1 20

## Una peruana postula a un escaño en el Parlamento de Cataluña

Hace 2 horas 9254 7 9

## (FOTOS) Nueva Zelanda de luto: murieron los 29 mineros bajo tierra

Hace 3 horas 30020 5 30

## Conozca los manjares limeños que están quedando en el olvido

Hace 1 hora 9380 13 22

## Leao Butrón estaría a un paso de firmar por Universitario de Deportes

Hace 2 horas 11577 1 36

## "Censurar Internet es una estupidez", asegura Lula da Silva

Hace 9 minutos 365 1 0

## Premios Luces 2010: ¿Quién fue la mejor actriz peruana del año?

Hace 1 hora 8998 5 0

- fútbol
- Peruano
- Libertadores
- Español
- Inglés
- Italiano
- Argentino
- Alemán
- Eliminatorias
- Champions
- x

Anterior Siguiente

- Todos
- Arequipa
- Brasil
- Cine
- Corea del Norte
- Corea del Sur
- Descentralizado 2010
- Estados Unidos
- FC Barcelona
- Fútbol alemán
- Fútbol español
- Fútbol Internacional
- Fútbol Nacional
- León de Huánuco
- Liguilla A
- Liguilla B
- Machu Picchu
- Ministerio del Interior
- Música
- Presidenciales 2011
- Reportube
- Selección peruana
- Televisión
- Televisión peruana
- Universidad de Yale
- Universidad San Martín

Ver todo
11:07

## Néstor Gorosito podría ser el nuevo técnico de Santiago Acasiete

El argentino, que dirigió la temporada pasada al Xerez, está camino a España para firmar con el equipo donde juega el peruano

10:59

## Empresaria explica la ausencia de Kenita Larraín en desfile a beneficio de niños

“Ella es muy profesional, pero se retrasó el desfile y su vuelo salía a las 10 p.m.” declaró Mary Chumbez

10:56

## Narradores de Fox Sports elogiaron a Mario Vargas Llosa en pleno partido del Real Madrid

Fernando Niembro mencionó al premio Nobel de Literatura y calificó de “imperdible” el último libre del escritor: ‘El sueño del celta’

10:51

## "Censurar Internet es una estupidez", asegura Lula da Silva

El mandatario brasileño se reunión por primera vez con destacados blogueros de su país

10:50

## El consumo excesivo de alcohol durante los fines de semana pone en riesgo el corazón

Estudio revela que beber desmedidamente durante uno o dos días está relacionado con las muertes coronarias

10:45

## Hoy reanudan marchas: huelga de trabajadores del Poder Judicial cumple 21 días

Delegaciones del interior del país y diversas bases de Lima se concentran en el Parque Universitario para luego marchar hacia el Congreso

10:35

## Miguel Bosé dice que el Gobierno de Chile convirtió rescate de mineros en un show

“Haber convertido un drama de este calibre a nivel “Gran Hermano” me parece que es lo peor de lo peor”, cuestionó el cantante español a su llegada a Santiago

10:35

## Médico de las estrellas fue sentenciado a 278 años de cárcel por abusar de 56 pacientes en Brasil

El condenado es conocido por ser el fundador de una clínica de fertilización en la que se han tratado las parejas de Pelé y del ex presidente y actual senador Fernando Collor de Mello

10:19

## Lady Gaga ahora tiene un restaurante de comida italiana

La polémica cantante ha invertido en su lugar favorito para comer pasta en Nueva York

10:18

## Sara Carbonero se aumentó el busto

La bella periodista acaba de cumplir un año de noviazgo con Iker Casillas y ese habría sido su mejor regalo para el golero del Real Madrid, campeón del mundo en Sudáfrica

10:14

## Adriana Zubiate criticó ausencia de Kenita Larraín en desfile benéfico

La modelo dejó plantada a la producción del evento y dijo que su vuelo de retorno ya estaba programado. La morena conductora señaló que a la chilena fue a la única que le pagaron

10:13

## Precio del nuevo sol estable y Bolsa de Valores de Lima sube en apertura

El precio del dólar estadounidense en el mercado paralelo es de 2,82 soles, mientras que en las ventanillas de los principales bancos se cotiza en 2,88 soles

10:11

## Una niña murió ahogada en una lavadora en Brasil

La pequeña metió la mitad del cuerpo a la máquina de lavar mientras esta se encontraba en pleno funcionamiento

10:08

## Paolo Zegna: “Muchos peruanos no saben lo que vale la fibra de vicuña”

El presidente del Grupo Ermenegildo Zegna estuvo unas horas en el Perú para conversar con el presidente Alan García de un tema urgente: preservar la calidad de la lana de este camélido

10:03

## Hermana del fallecido vocalista de Los Destellos fue capturada por proxenetismo y trata de personas

Delia Delgado también afronta juicios por hurto agravado, usurpación y estafa. Fue trasladada al Ministerio Público, donde está siendo interrogada y podría ser recluida en el penal de Chorrillos

09:58

## EN VIVO: siga el simulacro de tsunami que se realiza en El Callao

Siga AQUÍ a los pobladores de La Punt, quienes a tendrán once minutos para abandonar sus casas y trasladarse a las zonas seguras indicas por Defensa Civil

09:53

## Eto’o pidió disculpas a todo el mundo por su cabezazo, menos al jugador agredido

El camerunés se excusó con jugadores, árbitros, hinchas, su técnico y hasta el presidente de su club, pero ni mencionó al agredido Bostjan Cesar

09:50

## Premios Luces 2010: ¿Quién fue la mejor actriz del año?

La votación se cerrará el domingo 12 de diciembre, a las 12 de la noche. La invitación está hecha, su opinión será decisiva

09:48

## Fuego consumió anda del Señor de los Milagros en Surco

Según los devotos, quienes asistieron a la celebración por el 52 aniversario de la imagen, el siniestro habría sido provocado

09:48

## Ministro Hidalgo considera "un hombre extraordinario" a su cuestionado antecesor Fernando Barrios

Flamante titular del Interior no cree necesario auditar la gestión de quien fuera obligado a renunciar por el controversial cobro de 89 mil soles. “Es lamentable lo que ha pasado, es un hecho coyuntural”, dijo al respecto

09:45

## Energía y Minas le responde a Doe Run que tendrá que acudir a arbitraje

Minera exige al Estado Peruano hacerse responsable de los reclamos y demandas hechos por un grupo de pobladores de La Oroya, afectados por la contaminación, ante un tribunal de EE.UU.

09:36

## Encontraron a dos civiles muertos en el ataque norcoreano

Se trata de las primeras víctimas civiles que tras el bombardeo que ha complicado aún más las relaciones entre ambas Coreas

09:29

## La escritora española Ana María Matute obtuvo el trigésimo sexto Premio Cervantes

Se trata de la tercera mujer que ha obtenido el máximo premio de las letras hispanas, el mismo que Mario Vargas Llosa obtuvo en 1994. Sepa quiénes han ganado hasta ahora

09:19

## Hermanos Pinasco negocian nuevo proyecto con cadena extranjera

Aldo, Bruno y Chiara preparan la serie dramática “Los últimos días”, que trata sobre las decisiones que las personas tomarían al enterarse de que quedan pocas semanas para el fin del mundo

09:18

## Cifra de muertos por estampida en Camboya subió a 456

Las autoridades camboyanas continúan investigando las causas de la tragedia, mientras las familiares de los desaparecidos buscan a sus seres queridos en los hospitales

09:15

## Jefferson Farfán busca su pase a octavos de final de la Champions ante el Lyon

Este encuentro puede acabar con la ‘Foquita’ en la siguiente fase si es que su equipo gana y el Benfica cae derrotado en Tel Aviv. Se juega desde las 2:45 p.m.

09:04

## ¿En peligro de extinción? Rescatemos a los manjares limeños que están quedando en el olvido

Los pechitos de doncella, los besitos, los buñuelos y el sanguito son algunos de los postres que conquistaron paladares limeños y que hoy ya no endulzan las calles de la capital como antes

08:59

## Muy tarde: ex ministro Barrios envió voucher de devolución por liquidación cobrada indebidamente

De esta manera, el ingeniero Barrios Ipenza habría intentado salvar su fajín en Interior pero su suerte ya estaba echada

08:58

## Los Travolta tienen un nuevo bebe que se llamará Benjamin

Tanto la madre, Kelly Preston, como el pequeño están bien de salud, según un comunicado. El año pasado John y Kelly perdieron a Jett, su hijo mayor

08:48

## Leao Butrón estaría a un paso de firmar por la ‘U’

El portero de la San Martín fue fotografiado cuando ingresaba a las oficinas de Julio Pacheco y jugaría el 2011 con la camiseta crema

08:43

## Una peruana postula a un escaño en el Parlamento de Cataluña

Gisella Ramírez representa al oficialista Partido Socialista Catalán y es la primera mujer peruana en ser candidata a ocupar un escaño en el Parlamento de Cataluña

08:36

## Hallan veinte lobos marinos con signos de haber sido golpeados en playa de Talara

Mala imagen para el turismo en la región. Fiscalía del Medio Ambiente investigará quiénes están detrás de matanza registrada en Punta Balcones

08:27

## Conozca a los representantes del Perú en el Festival de Viña del Mar

“Destrozado y sin control”, canción compuesta por Francisco Murias e interpretada por la cantante Shaw, y “Vamos bailando”, de la autora e intérprete Fritzia Hualpa, nos representarán el próximo año en Chile. Elcomercio.pe habló con ellos

08:21

## Antiguos lambayecanos criaron felinos silvestres hace 3.500 años

Nuevos descubrimientos en complejo arqueológico Ventarrón. Hallazgos de restos dan detalles sobre la domesticación de diversas especies

08:14

## Víctor 'Chino' Rivera tiene fe en que el 2011 será mejor: “Quiero quedarme en Cristal”

El DT celeste rompió su silencio para asegurar que no ha rescindido con los rimenses y que tampoco ha firmado por Vallejo

07:58

## Crónica: la salida de Fernando Barrios por escandaloso cobro de 89 mil soles

El hasta ayer ministro del Interior duró dos meses y una semana en el cargo. Había sido uno de los funcionarios apristas más elogiados por Alan García

07:50

## ¿Lo empujaron? Cadete de la PNP quedó grave al caer de tercer piso y romperse el cráneo

El estado de Poul Aguilar Esteban (20), estudiante del primer año de la Escuela de Oficiales de la PNP, de Chorrillos, es delicado y está en observación

07:46

## Velásquez sobre el Caso Barrios: "Es un hecho de corrupción que pone en peligro la imagen del Gobierno"

Para el ex titular de la PCM el renunciante ministro del Interior cometió un “error gravísimo” al cobrar irregularmente S/.198 mil por dejar la presidencia de Essalud. Se mostró a favor de una investigación

07:38

## Casa Concha es local favorito para albergar piezas que devolverá Yale

Otras opciones son el palacio Cusicancha e incluso construir un nuevo museo

07:36

## iTunes vendió 2 millones de canciones de los Beatles en una semana

Cada tema cuesta 1,29 dólares. A ese nímero se suman los 450 mil álbumes de la banda de Liverpool que también se han vendido

07:25

## Transparencia: Alianzas para pasar valla electoral son una estafa para los electores

Pactos políticos no durarían más allá de las elecciones, advierte Percy Medina. Seis partidos buscan aliarse y solo uno tiene más de cinco años de inscrito

07:23

## Nueva Zelanda está de luto: murieron los 29 mineros atrapados bajo tierra

Desde el viernes pasado se había hecho todo lo posible para su rescate. Habrían muerto ahogados con monóxido de carbono y metano

07:17

## En Twitter se burlan de Alicia Machado por pedir la paz entre las “Chinas”

La ex reina de belleza venezolana quiso referirse a los ataques de Corea del Norte contra Corea del Sur pero su error le produjo una avalancha de críticas. Consternada, se dio de baja en la red social

07:14

## En lo que va de la semana, la Policía impuso 750 papeletas a los peatones

El jefe de la Policía de Tránsito, coronel José Alvarado, confía en que la campaña de educación vial muestre resultados positivos en los próximos meses

07:08

## Secretario general del PPC: "Hay gente inmadura en la dirigencia que está causando problemas"

El también congresista, Raúl Castro, sostuvo que en el PPC se ha cometido un error al conformar la dirigencia con miembros que no tienen más de 42 años. Reiteró que Daniel Córdova mintió y no respetó a su partido

07:02

## (Editorial) Otra grave amenaza a la paz mundial

01:51

## Wilmer Aguirre se une al clamor popular: pide que Jefferson Farfán sea perdonado

El ‘Zorrito’, que se encuentra en Lima de vacaciones, consideró que si Sergio Markarián le levanta el castigo a la ‘Foquita’ sería “con condiciones”

01:16

## Capitán de embarcaciones chinas sufrió el robo de casi diez mil dólares en hotel de San Miguel

En las dos horas que estuvo fuera de su habitación, desconocidos sustrajeron la maleta del marino chino que contenía el dinero de sus viáticos en el Perú

01:09

## Los 29 mineros atrapados en Nueva Zelanda habrían muerto tras una segunda explosión

“La nación está de duelo”, expresó el primer ministro neozelandés, John Key. Hoy miércoles se produjo un segundo estallido en la mina, por lo que ya no habría esperanza de hallar sobrevivientes

00:47

## Respuesta a ataque norcoreano: EE.UU. y Corea del Sur iniciarán maniobras militares conjuntas

Así lo decidieron tras una conversación telefónica sendos presidentes, Barack Obama y Lee Myung-bak. Las maniobras se realizarán el domingo en el Mar Amarillo (Mar Occidental) como medida disuasiva tras la agresión lanzada por Pyongyang

Más noticias

# elcomercio.pecerrar

En lo que va de la semana, la Policía impuso 750 papeletas a los peatones
elcomercio.pe te informa

### Casos Todos

### Personajes Todos

### Temas Todos

## Indisciplina en Panamá

## Rescate de mineros en Chile

## Las10+

## Mario Vargas Llosa, premio Nobel 2010

## Elecciones 2010

## Caso Comunicore

## Periodista peruana ¿espía de Rusia?

## Caso Joran van der Sloot

## Fernando Barrios

## Alan García

## Felipe de Borbón

## Magaly Medina

## Miguel Hidalgo

## Javier Velásquez Quesquén

## Sergio Markarián

## Letizia Ortiz

## Televisión

## Reportube

## Fútbol Internacional

## Ministerio del Interior

## Fútbol Nacional

## Corea del Sur

## Televisión peruana

## Corea del Norte

Portada | Vivo | Elecciones | Deportes | Espectáculos | Gastronomía | Blogs | Comunidad | Reportube |Clasificados | Edición Impresa | Mundial Sudáfrica 2010
CadElectoral | Archivo | Tags | Lo más buscado